* Output options: all can be turned on/off by adding/ removing the NO;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX NOfmterr;
* Remove default title, turn on new HTML graphics;
  TITLE; ODS GRAPHICS ON; ODS LISTING;

********************************************************************************;
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******;
********************************************************************************;

* Paste in the folder address where "GSS_Example.xlsx" is saved after = before ;
%LET filesave= C:\Dropbox\21SP_PSQF6242\PSQF6242_Example2;
* Using UIowa virtual desktop instead;
*%LET filesave= \\Client\C:\Dropbox\21SP_PSQF6242\PSQF6242_Example2;

* We can then refer to the filesave place by putting & in front and . behind it;

* IMPORT GSS_Example.xlsx data using filesave reference and exact file name;
* from the Excel workbook in DATAFILE= location from SHEET= ;
* New SAS file is in "work" library place with name "Example2";
* "GETNAMES" reads in the first row as variable names;
* DBMS=XLSX (can also use EXCEL or XLS for .xls files);
PROC IMPORT DATAFILE="&filesave.\GSS_Example.xlsx" 
            OUT=work.Example2 DBMS=XLSX REPLACE; 
     SHEET="GSS_Example"; 
     GETNAMES=YES; 
RUN;

* Create formats: set of value labels for categorical variables;
PROC FORMAT;
	VALUE Fmarry    1="1.Unmarried" 2="2.Married";
	VALUE Fgender   1="1.Man" 2="2.Woman";
	VALUE Fhappy    1="1.Unhappy" 2="2. Neither" 3="3.Fairly Happy" 
	                   4="4.Very Happy" 5="5.Completely Happy";
     VALUE Ffriends  1="1.Never" 2="2.Once/Year" 3="3. Several/Year"
	                   4="4.Once/Month" 5="5.Several/Month"
				    6="6.Several/Week" 7="7.Almost Daily";
RUN;
 
* DATA = create new dataset, SET = from OLD dataset;
* So DATA + SET means "save as itself" after these actions;
* All data transformations must happen inside a DATA+SET+RUN combo;
DATA work.Example2; SET work.Example2;
* Label variables and apply value formats for variables used below;
* LABEL name=    "name: Descriptive Variable Label";
  LABEL marry=   "marry: 2-Category Marital Status"
        gender=  "gender: 2-Category Gender Identity"
	   happy=   "happy: 5-Category Happy Rating"
	   friends= "friends: 7-Category Time with Friends"
	   educ=    "educ: Years of Education"
        income=  "income: Annual Income in 1000s";
* Apply value labels created above: name Format.;
  FORMAT marry Fmarry. gender Fgender. happy Fhappy. friends Ffriends.; 
* Make a copy of income to z-score next;
  incomeZ=income;
  LABEL incomeZ="incomeZ: Z-Scored Income";
* Example nonlinear transformation: natural-log transform;
  incomeLog=LOG(income);
  LABEL incomeLog="incomeLog: Log Annual Income";
RUN;

* Example linear transformation: z-scoring;
* This will over-write the original incomeZ with z-scored version;
PROC STANDARD DATA=work.Example2 OUT=work.Example2 MEAN=0 STD=1;
	VAR incomeZ;
RUN;
* Now dataset work.Example2 is ready to use; 

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example2_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

********************************************************************************;
*******     BIVARIATE ASSOCIATIONS FOR QUANTITATIVE VARIABLES            *******;
********************************************************************************;

* Request descriptive statistics for quantitative variables;
* NDEC=3 print 3s digits after decimal, NOLABELS suppresses labels;
TITLE "Descriptive statistics for quantitative variables";
PROC MEANS NDEC=3 NOLABELS N MEAN STDDEV MIN MAX DATA=work.Example2;
     VAR income incomeZ incomeLog educ;
RUN; 
* STDERR, ALPHA=.05, and CLM request SE and 95% CIs for mean;
PROC MEANS NDEC=3 NOLABELS N MEAN STDERR ALPHA=.05 CLM DATA=work.Example2;
     VAR income incomeZ incomeLog educ;
RUN; TITLE;

* Request Pearson correlations and p-values;
* FISHER gives CI (%=1-alpha) using r-to-z transformation;
TITLE "Pearson correlations for quantitative variables";
PROC CORR DATA=work.Example2 PEARSON FISHER(BIASADJ=YES ALPHA=.05);
     VAR income incomeZ incomeLog educ;
RUN; TITLE;
	
* Make scatterplot with regression lines to show predicted linear relations;
TITLE "Scatterplot and regression line for x=income and y=incomeLog";
PROC SGPLOT DATA=work.Example2;
     SCATTER x=income y=incomeLog;
     REG     x=income y=incomeLog;
RUN; TITLE;

TITLE "Scatterplot and regression line for x=educ and y=incomeLog";
PROC SGPLOT DATA=work.Example2;
     SCATTER x=educ y=incomeLog;
     REG     x=educ y=incomeLog;
RUN; TITLE;

********************************************************************************;
*******       BIVARIATE ASSOCIATIONS FOR ORDINAL VARIABLES               *******;
********************************************************************************;

* Request Spearman correlations and p-values;
* FISHER gives CI (%=1-alpha) using r-to-z transformation;
TITLE "Spearman correlations for rank-order quantitative and ordinal variables";
PROC CORR DATA=work.Example2 SPEARMAN FISHER(BIASADJ=YES ALPHA=.05);
     VAR income friends happy;
RUN; TITLE;
	
********************************************************************************;
*******        BIVARIATE ASSOCIATIONS FOR BINARY VARIABLES               *******;
********************************************************************************;

* Request cross-tabulation of categorical variables with percentages;
* NOROW NOCOL suppresses row- and column-specific frequencies;
* Options request chi-square test and expected frequencies;
TITLE "Cross-tabulations for binary variables gender and marry";
PROC FREQ DATA=work.Example2;
     TABLE gender*marry / NOROW NOCOL ALPHA=.05 CHISQ EXPECTED;
RUN; TITLE;

TITLE "Pearson correlation and CI for binary variables gender and marry";
PROC CORR DATA=work.Example2 PEARSON FISHER(BIASADJ=NO ALPHA=.05);
     VAR gender marry;
RUN; TITLE;

*********************************************************************************;
* Close output;
ODS RTF CLOSE;

